<?php
/**
 * Denver template Hooks for Grimlock.
 *
 * @package denver
 */

/**
 * Before Site Hooks.
 *
 * @see denver_grimlock_before_site()
 *
 * @since 1.0.0
 */
add_action( 'denver_before_site', 'denver_grimlock_before_site', 10 );

/**
 * Header Hooks.
 *
 * @see denver_header()
 * @see denver_grimlock_header()
 * @see denver_grimlock_before_content()
 *
 * @since 1.0.0
 */
remove_action( 'denver_header', 'denver_header',                  10 );
add_action(    'denver_header', 'denver_grimlock_header',         10 );
add_action(    'denver_header', 'denver_grimlock_before_content', 20 );

/**
 * Navigation Hooks.
 *
 * @see denver_grimlock_navbar_nav_menu()
 * @see denver_grimlock_vertical_navbar_nav_menu()
 *
 * @since 1.0.0
 */
add_action( 'grimlock_navbar_nav_menu',          'denver_grimlock_navbar_nav_menu',          10, 1 );
add_action( 'grimlock_vertical_navbar_nav_menu', 'denver_grimlock_vertical_navbar_nav_menu', 10, 1 );

/**
 * Footer Hooks.
 *
 * @see denver_footer()
 * @see denver_grimlock_footer()
 * @see denver_grimlock_after_content()
 *
 * @since 1.0.0
 */
remove_action( 'denver_footer', 'denver_footer',                 10 );
add_action(    'denver_footer', 'denver_grimlock_after_content', 10 );
add_action(    'denver_footer', 'denver_grimlock_footer',        20 );

/**
 * After Site Hooks.
 *
 * @see denver_grimlock_after_site()
 *
 * @since 1.0.0
 */
add_action( 'denver_after_site', 'denver_grimlock_after_site', 10 );

/**
 * Sidebar Hooks
 *
 * @see denver_sidebar_left()
 * @see denver_sidebar_right()
 * @see denver_grimlock_sidebar_left()
 * @see denver_grimlock_sidebar_right()
 *
 * @since 1.0.0
 */
remove_action( 'denver_sidebar_left', 'denver_sidebar_left',          10 );
add_action(    'denver_sidebar_left', 'denver_grimlock_sidebar_left', 10 );

remove_action( 'denver_sidebar_right', 'denver_sidebar_right',          10 );
add_action(    'denver_sidebar_right', 'denver_grimlock_sidebar_right', 10 );

/**
 * Before Posts Hooks.
 *
 * @see denver_grimlock_before_posts()
 *
 * @since 1.0.0
 */
remove_action( 'denver_before_posts', 'denver_before_posts',           10 );
add_action(    'denver_before_posts', 'denver_grimlock_before_posts',  10 );

/**
 * After Posts Hooks.
 *
 * @see denver_grimlock_after_posts()
 *
 * @since 1.0.0
 */
remove_action( 'denver_after_posts', 'denver_after_posts',          10 );
add_action(    'denver_after_posts', 'denver_grimlock_after_posts', 10 );

/**
 * Post Hooks.
 *
 * @see denver_post()
 * @see denver_grimlock_post()
 * @see denver_grimlock_the_post_thumbnail()
 * @see denver_grimlock_post_thumbnail_size()
 * @see denver_grimlock_the_excerpt()
 * @see denver_the_date()
 * @see denver_the_author()
 * @see denver_the_category_list()
 * @see denver_the_tag_list()
 * @see denver_the_post_format()
 * @see denver_the_sticky_mark()
 * @see denver_get_more_link_text()
 * @see denver_comments_link()
 *
 * @since 1.0.0
 */
remove_action( 'denver_post', 'denver_post',           10 );
add_action(    'denver_post', 'denver_grimlock_post',  10 );

add_action( 'grimlock_post_thumbnail',      'denver_grimlock_the_post_thumbnail',  10, 2 );
add_action( 'grimlock_post_excerpt',        'denver_grimlock_the_excerpt',         10, 1 );
add_action( 'grimlock_post_date',           'denver_the_date',                     10    );
add_action( 'grimlock_post_author',         'denver_the_author',                   10    );
add_action( 'grimlock_category_list',       'denver_the_category_list',            10    );
add_action( 'grimlock_post_tag_list',       'denver_the_tag_list',                 10    );
add_action( 'grimlock_post_format',         'denver_the_post_format',              10    );
add_action( 'grimlock_post_format',         'denver_the_sticky_mark',              10    );
add_filter( 'grimlock_post_more_link_text', 'denver_get_more_link_text',           10, 1 );
add_action( 'grimlock_comments_link',       'denver_comments_link',                10    );

/**
 * Search Hooks.
 *
 * @see denver_search_post()
 * @see denver_grimlock_search_post()
 *
 * @since 1.0.0
 */
remove_action( 'denver_search_post', 'denver_search_post',          10 );
add_action(    'denver_search_post', 'denver_grimlock_search_post', 10 );

/**
 * Single Post Hooks.
 *
 * @see denver_single()
 * @see denver_the_author_biography()
 * @see denver_grimlock_single()
 * @see denver_grimlock_the_post_navigation()
 *
 * @since 1.0.0
 */

remove_action( 'denver_single', 'denver_single',          10 );
add_action(    'denver_single', 'denver_grimlock_single', 10 );

remove_action( 'denver_the_post_navigation', 'the_post_navigation',                 10 );
add_action(    'denver_the_post_navigation', 'denver_grimlock_the_post_navigation', 10 );

add_action( 'grimlock_post_author_biography', 'denver_the_author_biography', 10 );

/**
 * Page Hooks.
 *
 * @see denver_page()
 * @see denver_grimlock_page()
 *
 * @since 1.0.0
 */
remove_action( 'denver_page', 'denver_page',          10 );
add_action(    'denver_page', 'denver_grimlock_page', 10 );

/**
 * 404 Page Hooks.
 *
 * @see denver_404()
 * @see denver_grimlock_404()
 *
 * @since 1.1.0
 */
remove_action( 'denver_404', 'denver_404',          10 );
add_action(    'denver_404', 'denver_grimlock_404', 10 );

/**
 * Homepage Hooks.
 *
 * @see denver_grimlock_homepage()
 *
 * @since 1.0.0
 */
add_action( 'denver_homepage', 'denver_grimlock_homepage', 10 );

/**
 * Other Hooks.
 *
 * @see denver_grimlock_remove_actions()
 *
 * @since 1.0.0
 */
remove_filter( 'nav_menu_css_class', 'denver_nav_menu_css_class', 10 );

add_action( 'template_redirect', 'denver_grimlock_remove_actions', 10 );

