<?php
/**
 * Denver Jetpack Class
 *
 * @link https://jetpack.com/
 *
 * @package  denver
 * @author   Themosaurus
 * @since    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Denver_Jetpack' ) ) :
	/**
	 * The Denver Jetpack integration class
	 */
	class Denver_Jetpack {
		/**
		 * Setup class.
		 *
		 * @since 1.0.0
		 */
		public function __construct() {
			add_action( 'after_setup_theme', array( $this, 'setup' ), 10 );
		}

		/**
		 * Jetpack setup function.
		 *
		 * @since 1.0.0
		 *
		 * @link https://jetpack.me/support/infinite-scroll/
		 * @link https://jetpack.me/support/responsive-videos/
		 */
		public function setup() {
			// Add theme support for Infinite Scroll.
			add_theme_support( 'infinite-scroll', array(
				'container' => 'posts',
				'render'    => array( $this, 'infinite_scroll_render' ),
				'footer'    => false,
			) );

			// Add theme support for Responsive Videos.
			add_theme_support( 'jetpack-responsive-videos' );
		}

		/**
		 * Custom render function for Infinite Scroll.
		 *
		 * @since 1.0.0
		 */
		public function infinite_scroll_render() {
			while ( have_posts() ) {
				the_post();
				if ( is_search() ) :
					get_template_part( 'template-parts/content', 'search' );
				else :
					get_template_part( 'template-parts/content', get_post_format() );
				endif;
			}
		}
	}
endif;

return new Denver_Jetpack();
