<?php
/**
 * Denver template functions.
 *
 * @package denver
 */

if ( ! function_exists( 'denver_nav_menu_css_class' ) ) :
	/**
	 * Add CSS classes to default primary menu.
	 *
	 * @since 1.0.0
	 *
	 * @param array    $classes The array of CSS classes that are applied to the menu item's `<li>` element.
	 * @param WP_Post  $item    The current menu item.
	 * @param stdClass $args    An object of wp_nav_menu() arguments.
	 * @param int      $depth   Depth of menu item. Used for padding.
	 *
	 * @return array   The filtred array of CSS classes that are applied to the menu item's `<li>` element.
	 */
	function denver_nav_menu_css_class( $classes, $item, $args, $depth ) {
		if ( 'primary' === $args->theme_location ) {
			$classes[] = 'list-inline-item';
		}
		return $classes;
	}
endif;

if ( ! function_exists( 'denver_header' ) ) :
	/**
	 * Prints HTML for the header.
	 *
	 * @since 1.0.0
	 */
	function denver_header() {
		?>
		<header id="masthead" class="site-header region" role="banner">
			<div class="region__container">
				<div class="site-branding">
					<h1 class="screen-reader-text"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php
					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
					<?php
					endif; ?>
				</div><!-- .site-branding -->

				<nav id="site-navigation" class="main-navigation pb-0" role="navigation">
					<a class="btn btn-primary d-lg-none btn-block" data-toggle="collapse" href="#collapseExample" aria-expanded="false" aria-controls="menu">
						<?php esc_html_e( 'Menu', 'denver' ); ?>
					</a>
					<div class="collapse" id="collapseExample">
						<?php
						if ( has_nav_menu( 'primary' ) ) :
							wp_nav_menu( array(
								'theme_location' => 'primary',
								'menu_id'        => 'primary-menu',
								'menu_class'     => 'navbar-nav list-inline',
							) );
						endif; ?>
					</div><!-- .collapse -->
				</nav><!-- #site-navigation -->
			</div><!-- .container -->
		</header><!-- #masthead -->

		<div id="content" class="site-content region" tabindex="-1">
			<div class="region__container">
				<div class="region__row">
		<?php
	}
endif;

if ( ! function_exists( 'denver_footer' ) ) :
	/**
	 * Prints footer in page.
	 *
	 * @since 1.0.0
	 */
	function denver_footer() {
		?>
				</div><!-- .region__row -->
			</div><!-- .region__container -->
		</div><!-- #content -->

		<footer id="colophon" class="site-footer region" role="contentinfo">
			<div class="region__container">
				<div class="site-info">
					<a href="<?php echo esc_url( __( 'https://wordpress.org/', 'denver' ) ); ?>">
						<?php
						// translators: %s: The WordPress brand name.
						printf( esc_html__( 'Proudly powered by %s', 'denver' ), 'WordPress' ); ?>
					</a>
					<span class="sep"> | </span>
					<?php
					// translators: %s: The denver brand name.
					printf( esc_html__( 'Denver theme by %s.', 'denver' ), '<a href="http://www.themosaurus.com" rel="designer">Themosaurus</a>' ); ?>
				</div><!-- .site-info -->
			</div><!-- .container -->
		</footer><!-- #colophon -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_sidebar_left' ) ) :
	/**
	 * Prints left sidebar in page.
	 *
	 * @since 1.0.0
	 */
	function denver_sidebar_left() {
		?>
		<aside id="secondary-left" class="widget-area sidebar region__col region__col--1" role="complementary">
			<?php
			if ( is_active_sidebar( 'sidebar-1' ) ) :
				dynamic_sidebar( 'sidebar-1' );
			endif; ?>
		</aside><!-- #secondary-left -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_sidebar_right' ) ) :
	/**
	 * Prints right sidebar in page.
	 *
	 * @since 1.0.0
	 */
	function denver_sidebar_right() {
		?>
		<aside id="secondary-right" class="widget-area sidebar region__col region__col--3" role="complementary">
			<?php
			if ( is_active_sidebar( 'sidebar-2' ) ) :
				dynamic_sidebar( 'sidebar-2' );
			endif; ?>
		</aside><!-- #secondary-left -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_before_posts' ) ) :
	/**
	 * Prints markups to open the posts wrapper.
	 *
	 * @since 1.0.0
	 */
	function denver_before_posts() {
		?>
		<div id="posts">
		<?php
	}
endif;

if ( ! function_exists( 'denver_after_posts' ) ) :
	/**
	 * Prints markups to close the posts wrapper.
	 *
	 * @since 1.0.0
	 */
	function denver_after_posts() {
		?>
		</div><!-- #posts -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_post' ) ) :
	/**
	 * Prints HTML for the post.
	 *
	 * @since 1.0.0
	 */
	function denver_post() {
		?>
		<?php
		if ( 'post' === get_post_type() ) : ?>
			<div class="entry-meta labels">
				<?php
				denver_the_post_format();
				denver_the_sticky_mark(); ?>
			</div>
		<?php
		endif; ?>

		<header class="entry-header clearfix">
			<?php
			if ( is_single() ) :
				the_title( '<h1 class="entry-title">', '</h1>' );
			else :
				the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );
			endif;

			if ( 'post' === get_post_type() ) : ?>
				<div class="entry-meta">
					<?php
					denver_the_date(); ?> <?php denver_the_author(); ?>
				</div><!-- .entry-meta -->
			<?php
			endif; ?>
		</header><!-- .entry-header -->

		<div class="entry-content clearfix">
			<?php
			the_content( denver_get_more_link_text() );
			wp_link_pages( array(
				'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'denver' ),
				'after'  => '</div>',
			) ); ?>
		</div><!-- .entry-content -->

		<footer class="entry-footer clearfix">
			<?php
			denver_the_category_list();
			denver_the_tag_list();
			denver_comments_link();

			if ( get_edit_post_link() ) :
				edit_post_link(
					sprintf(
						/* translators: %s: Name of current post */
						esc_html__( 'Edit %s', 'denver' ),
						the_title( '<span class="screen-reader-text sr-only">"', '"</span>', false )
					),
					'<span class="edit-link">',
					'</span>'
				);
			endif; ?>
		</footer><!-- .entry-footer -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_search_post' ) ) :
	/**
	 * Prints HTML for the post.
	 *
	 * @since 1.0.0
	 */
	function denver_search_post() {
		?>
		<?php
		if ( 'post' === get_post_type() ) : ?>
			<div class="entry-meta labels">
				<?php
				denver_the_post_format();
				denver_the_sticky_mark(); ?>
			</div>
		<?php
		endif; ?>

		<header class="entry-header clearfix">
			<?php
			the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );

			if ( 'post' === get_post_type() ) : ?>
				<div class="entry-meta">
					<?php
					denver_the_date(); ?> <?php denver_the_author(); ?>
				</div><!-- .entry-meta -->
			<?php
			endif; ?>
		</header><!-- .entry-header -->

		<div class="entry-summary clearfix">
			<?php the_excerpt(); ?>
		</div><!-- .entry-content -->

		<footer class="entry-footer clearfix">
			<?php
			denver_the_category_list();
			denver_the_tag_list();
			denver_comments_link();

			if ( get_edit_post_link() ) :
				edit_post_link(
					sprintf(
						/* translators: %s: Name of current post */
						esc_html__( 'Edit %s', 'denver' ),
						the_title( '<span class="screen-reader-text sr-only">"', '"</span>', false )
					),
					'<span class="edit-link">',
					'</span>'
				);
			endif; ?>
		</footer><!-- .entry-footer -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_single' ) ) :
	/**
	 * Prints HTML for the single post.
	 *
	 * @since 1.0.0
	 */
	function denver_single() {
		?>
		<header class="entry-header clearfix">
			<?php
			do_action( 'denver_breadcrumb' );
			the_title( '<h1 class="entry-title">', '</h1>' );

			if ( 'post' === get_post_type() ) : ?>
				<div class="entry-meta">
					<?php denver_the_date(); ?> <?php denver_the_author(); ?>
				</div><!-- .entry-meta -->
			<?php
			endif; ?>
		</header><!-- .entry-header -->

		<div class="entry-content clearfix">
			<?php
			the_content();
			wp_link_pages( array(
				'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'denver' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text sr-only">' . esc_html__( 'Page', 'denver' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text sr-only">, </span>',
			) );

			denver_the_author_biography(); ?>
		</div><!-- .entry-content -->

		<footer class="entry-footer clearfix">
			<?php
			denver_the_category_list();
			denver_the_tag_list();
			denver_the_post_format();

			if ( get_edit_post_link() ) :
				edit_post_link(
					sprintf(
						/* translators: %s: Name of current post */
						esc_html__( 'Edit %s', 'denver' ),
						the_title( '<span class="screen-reader-text sr-only">"', '"</span>', false )
					),
					'<span class="edit-link">',
					'</span>'
				);
			endif; ?>
		</footer><!-- .entry-footer -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_page' ) ) :
	/**
	 * Prints HTML for the page.
	 *
	 * @since 1.0.0
	 */
	function denver_page() {
		?>
		<header class="entry-header clearfix">
			<?php
			do_action( 'denver_breadcrumb' );
			the_title( '<h1 class="entry-title">', '</h1>' ); ?>
		</header><!-- .entry-header -->

		<div class="entry-content clearfix">
			<?php
			the_content();
			wp_link_pages( array(
				'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'denver' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text sr-only">' . esc_html__( 'Page', 'denver' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text sr-only">, </span>',
			) ); ?>
		</div><!-- .entry-content -->

		<?php
		if ( get_edit_post_link() ) : ?>
			<footer class="entry-footer clearfix">
				<?php
				edit_post_link(
					sprintf(
						/* translators: %s: Name of current post */
						esc_html__( 'Edit %s', 'denver' ),
						the_title( '<span class="screen-reader-text sr-only">"', '"</span>', false )
					),
					'<span class="edit-link">',
					'</span>'
				); ?>
			</footer><!-- .entry-footer -->
		<?php
		endif;
	}
endif;

if ( ! function_exists( 'denver_404' ) ) :
	/**
	 * Prints HTML for the 404 page.
	 *
	 * @since 1.1.0
	 */
	function denver_404() {
		?>
		<section class="error-404 not-found region__col">

			<header class="page-header text-center">
				<?php do_action( 'denver_breadcrumb' ); ?>
				<h1 class="page-title"><?php esc_html_e( 'Oops! That page can&rsquo;t be found.', 'denver' ); ?></h1>
			</header><!-- .page-header -->

			<div class="page-content">
				<p class="text-center"><?php esc_html_e( 'It looks like nothing was found at this location. Maybe try one of the links below or a search?', 'denver' ); ?></p>

				<div class="text-center mb-4">
					<div class="d-inline-block">
						<?php get_search_form(); ?>
					</div>
				</div>

				<div class="row mt-4">

					<div class="col-sm-4 pt-2 pb-2">
						<?php the_widget( 'WP_Widget_Recent_Posts' ); ?>
					</div>

					<div class="col-sm-4 pt-2 pb-2">
						<?php
						// Only show the widget if site has multiple categories.
						if ( denver_categorized_blog() ) : ?>

							<div class="widget widget_categories">
								<h2 class="widgettitle"><?php esc_html_e( 'Categories', 'denver' ); ?></h2>
								<ul>
									<?php
									wp_list_categories( array(
										'orderby'    => 'count',
										'order'      => 'DESC',
										'show_count' => 1,
										'title_li'   => '',
										'number'     => 5,
									) ); ?>
								</ul>
							</div><!-- .widget -->

						<?php endif; ?>
					</div>

					<div class="col-sm-4 pt-2 pb-2">
						<?php
						// translators: %1$s: smiley.
						$archive_content = '<p>' . sprintf( esc_html__( 'Try looking in the monthly archives. %1$s', 'denver' ), convert_smilies( ':)' ) ) . '</p>';
						the_widget( 'WP_Widget_Archives', 'dropdown=1', "after_title=</h2>$archive_content" ); ?>
					</div>

				</div>

				<div class="row mb-4">
					<div class="col pt-2 pb-2">
						<?php the_widget( 'WP_Widget_Tag_Cloud' ); ?>
					</div>
				</div>

			</div><!-- .page-content -->

		</section><!-- .error-404 -->
		<?php
	}
endif;

if ( ! function_exists( 'denver_the_date' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 *
	 * @since 1.0.0
	 */
	function denver_the_date() {
		if ( 'post' === get_post_type() ) {
			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
			}

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
			);

			$posted_on = sprintf(
				'<span class="posted-on-label">' . esc_html__( 'Posted on', 'denver' ) . ' </span>%s',
				'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
			);

			echo '<span class="posted-on">' . $posted_on . ' </span>'; // WPCS: XSS OK.
		}
	}
endif;

if ( ! function_exists( 'denver_the_author' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 *
	 * @since 1.0.0
	 */
	function denver_the_author() {
		if ( 'post' === get_post_type() ) {
			$byline = sprintf(
				'<span class="byline-label">' . esc_html__( 'by', 'denver' ) . ' </span>%1$s %2$s',
				'<span class="author-avatar">' . get_avatar( get_the_author_meta( 'ID' ), 32 ) . '</span>',
				'<span class="author-vcard vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
			);
			echo '<span class="byline author">' . $byline . ' </span>'; // WPCS: XSS OK.
		}
	}
endif;

if ( ! function_exists( 'denver_the_sticky_mark' ) ) :
	/**
	 * Prints HTML for "Featured" as Boostrap label when the post is sticky.
	 *
	 * @since 1.0.0
	 */
	function denver_the_sticky_mark() {
		if ( is_sticky() ) : ?>
			<span class="badge badge-primary post-sticky"><i class="fa fa-thumb-tack"></i> <?php esc_html_e( 'Sticky', 'denver' ); ?></span>
		<?php
		endif;
	}
endif;

if ( ! function_exists( 'denver_get_more_link_text' ) ) :
	/**
	 * Get the HTML for the more link.
	 *
	 * @since 1.0.0
	 *
	 * @return string The more link text.
	 */
	function denver_get_more_link_text() {
		$allowed_html = array(
			'span' => array(
				'class' => array(),
			),
		);

		$more_link_text = sprintf(
			/* translators: %s: Name of current post. */
			wp_kses( __( 'Continue reading %1$s %2$s', 'denver' ), $allowed_html ),
			the_title( '<span class="screen-reader-text sr-only">"', '"</span>', false ),
			'<span class="meta-nav">&rarr;</span>'
		);
		return apply_filters( 'denver_more_link_text', $more_link_text );
	}
endif;

if ( ! function_exists( 'denver_the_category_list' ) ) :
	/**
	 * Prints HTML with meta information for the categories.
	 *
	 * @since 1.0.0
	 */
	function denver_the_category_list() {
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'denver' ) );
			if ( $categories_list && denver_categorized_blog() ) {
				printf( '<span class="cat-links"><span class="cat-links-label">' . esc_html__( 'Posted in', 'denver' ) . ' </span>%1$s </span>', $categories_list ); // WPCS: XSS OK.
			}
		}
	}
endif;

if ( ! function_exists( 'denver_the_tag_list' ) ) :
	/**
	 * Prints HTML with meta information for the post tags.
	 *
	 * @since 1.0.0
	 */
	function denver_the_tag_list() {
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'denver' ) );
			if ( $tags_list ) {
				printf( '<span class="tags-links"><span class="tag-links-label">' . esc_html__( 'Tagged', 'denver' ) . ' </span>%1$s </span>', $tags_list ); // WPCS: XSS OK.
			}
		}
	}
endif;

if ( ! function_exists( 'denver_the_post_format' ) ) :
	/**
	 * Prints HTML for the post format as Boostrap label.
	 *
	 * @since 1.0.0
	 */
	function denver_the_post_format() {
		$post_format = get_post_format();
		if ( false !== $post_format ) :
			$post_format_string = get_post_format_string( $post_format );

			// translators: %s: The post format name.
			$link_title = sprintf( esc_html__( 'View posts formatted as %s', 'denver' ), strtolower( $post_format_string ) ); ?>
			<a href="<?php echo esc_url( get_post_format_link( $post_format ) ); ?>" title="<?php echo esc_attr( $link_title ); ?>" class="badge badge-primary post-format post-format--<?php echo esc_attr( $post_format ); ?>">
				<i class="fa fa-<?php echo esc_attr( $post_format ); ?>"></i> <?php echo esc_html( $post_format_string ); ?>
			</a>
		<?php
		endif;
	}
endif;

if ( ! function_exists( 'denver_comments_link' ) ) :
	/**
	 * Prints HTML with meta information for the comments.
	 *
	 * @since 1.0.0
	 */
	function denver_comments_link() {
		$has_comments_link = ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() );
		if ( apply_filters( 'denver_has_comments_link', $has_comments_link ) ) {
			echo ' <span class="comments-link">';
			comments_popup_link( esc_html__( 'Leave a comment', 'denver' ), esc_html__( '1 Comment', 'denver' ), esc_html__( '% Comments', 'denver' ) );
			echo '</span>';
		}
	}
endif;

if ( ! function_exists( 'denver_the_author_biography' ) ) :
	/**
	 * Display navigation the author biography.
	 *
	 * @since 1.0.0
	 */
	function denver_the_author_biography() {
		if ( '' !== get_the_author_meta( 'description' ) && 'post' === get_post_type() ) : ?>
			<hr />
			<div class="media author-info">
				<?php
				$args = array(
					'class' => array( 'd-flex', 'align-self-start', 'mr-3' ),
				);
				echo get_avatar( get_the_author_meta( 'user_email' ), 128, '', '', $args ); ?>
				<div class="author-description media-body">
					<h4 class="author-title media-heading"><span class="author-heading"><?php esc_html_e( 'By', 'denver' ); ?></span> <?php echo get_the_author(); ?></h4>
					<div class="author-bio">
						<?php the_author_meta( 'description' ); ?>
						<div class="mt-1">
							<a class="author-link" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author">
								<?php
								// translators: %s: The post author name.
								printf( esc_html__( 'View all posts by %s', 'denver' ), get_the_author() ); ?>
							</a>
						</div>
					</div><!-- .author-bio -->
				</div><!-- .author-description -->
			</div><!-- .author-info -->
			<hr />
		<?php
		endif;
	}
endif;

/**
 * Template for comments and pingbacks.
 */
if ( ! function_exists( 'denver_comment' ) ) :
	/**
	 * Prints the HTML for the comments and pingbacks.
	 *
	 * @since 1.0.0
	 *
	 * @param object $comment The comment to display.
	 * @param array  $args    The array of arguments for the comment display.
	 * @param int    $depth   The depth of the list of comment replies to display.
	 */
	function denver_comment( $comment, $args, $depth ) {
		/**
		 * TODO: Check if following bit is required because WP Coding Standards are prohibiting use of globals ("ERROR: Overriding WordPress globals is prohibited.")
		 *
		 * $GLOBALS['comment'] = $comment;
		 */

		if ( 'pingback' === $comment->comment_type || 'trackback' === $comment->comment_type ) : ?>

			<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
				<p class="comment-body text-center">
					<?php esc_html_e( 'Pingback:', 'denver' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( esc_html__( 'Edit', 'denver' ), '<span class="edit-link">', '</span>' ); ?>
				</p><!-- .comment-body -->
			</li><!-- #-comment-## -->

		<?php else : ?>

		<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? 'media' : 'media parent' ); ?>>

			<div id="div-comment-<?php comment_ID(); ?>" class="comment-main comment-main-<?php comment_ID(); ?>">

				<div class="comment-img">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
						<?php
						if ( 0 !== $args['avatar_size'] ) :
							echo get_avatar( $comment, $args['avatar_size'] );
						endif; ?>
					</a>
				</div><!-- .comment-img -->

				<div class="comment-body media-body">

					<h5 class="comment-title media-heading">
						<span class="fn"><?php echo get_comment_author_link(); ?></span>
						<time datetime="<?php comment_time( 'c' ); ?>" class="comment-time small">
							<?php
							// translators: %1$s: The comment date.
							// translators: %2$s: The comment time.
							printf( esc_html__( '%1$s at %2$s', 'denver' ), get_comment_date(), get_comment_time() ); ?>
						</time><!-- .comment-time -->
					</h5><!-- .media-heading -->

					<div class="comment-content">
						<?php comment_text(); ?>
					</div><!-- .comment-content -->

					<footer class="comment-meta">

						<?php
						// @codingStandardsIgnoreLine
						if ( '0' == $comment->comment_approved ) : ?>
							<p class="alert alert-danger comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'denver' ); ?></p>
						<?php
						endif; ?>

						<ul class="nav nav-inline">
							<li class="nav-item">
								<?php
								$args = array_merge( $args, array(
									'add_below' => 'div-comment',
									'depth'     => $depth,
									'max_depth' => $args['max_depth'],
									'before'    => '<span class="reply">',
									'after'     => '</span>',
								) );

								comment_reply_link( $args ); ?>
							</li>

							<li class="nav-item">
								<?php edit_comment_link( esc_html__( 'Edit', 'denver' ), '<span class="edit-link">', '</span>' ); ?>
							</li>
						</ul>

					</footer><!-- .comment-meta -->

				</div><!-- .comment-body -->

			</div><!-- .comment-main -->

			<!-- "</li>" No closure tag, wp_list_comments "end-callback" do the job -->
		<?php
		endif;
	}
endif; // ends check for `denver_comment()`.

if ( ! function_exists( 'denver_get_the_archive_title' ) ) :
	/**
	 * Change the retrieved the archive title based on the queried object.
	 *
	 * @since 1.0.0
	 *
	 * @param  string $title The title for the archive page.
	 *
	 * @return string        The filtred title for the archive page.
	 */
	function denver_get_the_archive_title( $title ) {
		if ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$title = single_tag_title( '', false );
		} elseif ( is_author() ) {
			$title = '<span class="vcard">' . get_the_author() . '</span>';
		} elseif ( is_year() ) {
			$title = get_the_date( esc_html__( 'Y', 'denver' ) );
		} elseif ( is_month() ) {
			$title = get_the_date( esc_html__( 'F Y', 'denver' ) );
		} elseif ( is_day() ) {
			$title = get_the_date( esc_html__( 'F j, Y', 'denver' ) );
		} elseif ( is_tax( 'post_format' ) ) {
			if ( is_tax( 'post_format', 'post-format-aside' ) ) {
				$title = esc_html__( 'Asides', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
				$title = esc_html__( 'Galleries', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
				$title = esc_html__( 'Images', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
				$title = esc_html__( 'Videos', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
				$title = esc_html__( 'Quotes', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
				$title = esc_html__( 'Links', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
				$title = esc_html__( 'Statuses', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
				$title = esc_html__( 'Audio', 'denver' );
			} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
				$title = esc_html__( 'Chats', 'denver' );
			}
		} elseif ( is_post_type_archive() ) {
			$title = post_type_archive_title( '', false );
		} elseif ( is_tax() ) {
			$title = single_term_title( '', false );
		} else {
			$title = esc_html__( 'Archives', 'denver' );
		} // End if.

		return $title;
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since 1.0.0
 *
 * @return bool True if a blog has more than 1 category, false otherwise.
 */
function denver_categorized_blog() {
	$all_the_cool_cats = get_transient( 'denver_categories' );
	if ( false === ( $all_the_cool_cats ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'denver_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so denver_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so denver_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in denver_categorized_blog.
 *
 * @since 1.0.0
 */
function denver_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'denver_categories' );
}
add_action( 'edit_category', 'denver_category_transient_flusher' );
add_action( 'save_post',     'denver_category_transient_flusher' );
